from django.contrib.auth.admin import UserAdmin, admin

from .models import User


@admin.register(User)
class UserAdminCustom(UserAdmin):
    readonly_fields = ('jwt_token',)
    fieldsets = UserAdmin.fieldsets + (
        ('Информация', {'fields': (
            'jwt_token',)}),
    )


import uuid

from django.db.models.signals import post_save
from django.db.transaction import on_commit
from django.dispatch import receiver

from .models import PhoneCode
from .tasks import send_sms_async


@receiver(post_save, sender=PhoneCode, dispatch_uid=uuid.uuid4())
def phone_code_post_save(sender, instance, created, **kwargs):
    if created:
        on_commit(lambda: send_sms_async.delay(instance.pk))



from django.contrib.auth import get_user_model
from django.utils.translation import gettext as _
from phonenumber_field.serializerfields import PhoneNumberField
from rest_framework import serializers

User = get_user_model()


class EntrySerializer(serializers.Serializer):
    phone_number = PhoneNumberField()


class AuthSerializer(serializers.Serializer):
    phone_number = PhoneNumberField()
    code = serializers.IntegerField()


class ChangePhoneNumberSerializer(serializers.Serializer):
    new_phone_number = PhoneNumberField()



class DefaultUserSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        fields = [
            'pk',
            'first_name',
            'last_name'
        ]